diff --git a/.gitignore b/.gitignore
index 84085b0..6c60231 100644
--- a/.gitignore
+++ b/.gitignore
@@ -9,13 +9,3 @@ scribus-1.3.8.tar.bz2
/scribus-1.4.4-free.tar.xz
/scribus-1.4.5-free.tar.xz
/scribus-1.4.6-free.tar.xz
-/scribus-1.5.5-free.tar.xz
-/scribus-1.5.6.tar.xz
-/scribus-1.5.6-free.tar.xz
-/scribus-1.5.6.1-free.tar.xz
-/scribus-1.5.8-free.tar.xz
-/scribus-1.6.0-free.tar.xz
-/scribus-1.6.1-free.tar.xz
-/scribus-1.6.3-free.tar.xz
-/scribus-1.6.4-free.tar.xz
-/scribus-1.6.5-free.tar.xz
diff --git a/scribus-1.4.2-nonfree.patch b/scribus-1.4.2-nonfree.patch
new file mode 100644
index 0000000..5c202a4
--- /dev/null
+++ b/scribus-1.4.2-nonfree.patch
@@ -0,0 +1,60 @@
+Index: scribus-1.4.2/scribus/CMakeLists.txt
+===================================================================
+--- scribus-1.4.2.orig/scribus/CMakeLists.txt
++++ scribus-1.4.2/scribus/CMakeLists.txt
+@@ -2,7 +2,6 @@ IF(WIN32)
+ ADD_DEFINITIONS(-DQT_DLL)
+ ENDIF(WIN32)
+
+-ADD_SUBDIRECTORY(doc)
+ ADD_SUBDIRECTORY(dtd)
+ ADD_SUBDIRECTORY(manpages)
+ ADD_SUBDIRECTORY(colormgmt)
+Index: scribus-1.4.2/scribus/helpbrowser.cpp
+===================================================================
+--- scribus-1.4.2.orig/scribus/helpbrowser.cpp
++++ scribus-1.4.2/scribus/helpbrowser.cpp
+@@ -716,7 +716,7 @@ QString HelpBrowser::historyFile()
+
+ void HelpBrowser::displayNoHelp()
+ {
+- QString noHelpMsg=tr("
Sorry, no manual is installed!
Please see:
- http://docs.scribus.net for updated documentation
- http://www.scribus.net for downloads
",
++ QString noHelpMsg=tr("Sorry, the manual is not installed because it is not freely distributable and thus can't be included in Fedora!
Please see:
- http://docs.scribus.net for updated documentation
- http://www.scribus.net for downloads
",
+ "HTML message for no documentation available to show");
+
+ textBrowser->setText(noHelpMsg);
+Index: scribus-1.4.2/scribus/profiles/CMakeLists.txt
+===================================================================
+--- scribus-1.4.2.orig/scribus/profiles/CMakeLists.txt
++++ scribus-1.4.2/scribus/profiles/CMakeLists.txt
+@@ -6,7 +6,5 @@ INSTALL(FILES
+ GenericCMYK.icm
+ GenericCMYK.txt
+ Readme
+-sRGB.icm
+-srgb.license
+ DESTINATION ${SHAREDIR}profiles
+ )
+diff -up scribus-1.4.4/resources/editorconfig/CMakeLists.txt.no-dot scribus-1.4.4/resources/editorconfig/CMakeLists.txt
+--- scribus-1.4.4/resources/editorconfig/CMakeLists.txt.no-dot 2014-06-06 17:22:12.258966553 -0400
++++ scribus-1.4.4/resources/editorconfig/CMakeLists.txt 2014-06-06 17:22:16.326936717 -0400
+@@ -12,7 +12,6 @@ gnuplot.png
+ 300_lilypond.xml
+ lilypond.png
+ 400_dot.xml
+-dot.svg
+ 500_povray.xml
+ povray_32.png
+
+diff -up scribus-1.4.5/resources/swatches/CMakeLists.txt.nonfree scribus-1.4.5/resources/swatches/CMakeLists.txt
+--- scribus-1.4.5/resources/swatches/CMakeLists.txt.nonfree 2016-01-12 17:41:12.379774049 -0500
++++ scribus-1.4.5/resources/swatches/CMakeLists.txt 2016-01-12 17:41:22.219677148 -0500
+@@ -8,7 +8,7 @@ FILE( GLOB EPS_PALETTES *.eps )
+ FILE( GLOB RTF_LICENSES *.rtf )
+
+ #Avoid CMakeLists.txt
+-SET(TXT_LICENSES "${CMAKE_CURRENT_SOURCE_DIR}/COPYING_RESENE.txt" "${CMAKE_CURRENT_SOURCE_DIR}/Japanese_Traditional_README.txt")
++SET(TXT_LICENSES "${CMAKE_CURRENT_SOURCE_DIR}/Japanese_Traditional_README.txt")
+
+ INSTALL(FILES ${GIMP_STYLE_PALETTES} ${XML_PALETTES} ${EPS_PALETTES} ${RTF_LICENSES} ${TXT_LICENSES}
+ DESTINATION ${SHAREDIR}swatches
diff --git a/scribus-1.4.4-qreal_double.patch b/scribus-1.4.4-qreal_double.patch
new file mode 100644
index 0000000..9b3ec95
--- /dev/null
+++ b/scribus-1.4.4-qreal_double.patch
@@ -0,0 +1,138 @@
+Description: Avoid qreal/double type clashes on ARM
+Author: Colin Watson
+Forwarded: no
+Last-Update: 2013-05-16
+
+--- scribus-1.4.2.dfsg+r18267.orig/scribus/scribus.h
++++ scribus-1.4.2.dfsg+r18267/scribus/scribus.h
+@@ -466,7 +466,7 @@ public slots:
+ /** Fragt nach den Farben */
+ // void GetBrushPen();
+ /** Erzeugt einen Rahmen */
+- void MakeFrame(int f, int c, double *vals);
++ void MakeFrame(int f, int c, qreal *vals);
+ //** Loescht ein Element */
+ //void DeleteObjekt();
+ /** Duplicate current item */
+--- scribus-1.4.2.dfsg+r18267.orig/scribus/pageitem.cpp
++++ scribus-1.4.2.dfsg+r18267/scribus/pageitem.cpp
+@@ -4597,7 +4597,7 @@ void PageItem::copyToCopyPasteBuffer(str
+
+
+ //Moved from View
+-void PageItem::SetFrameShape(int count, double *vals)
++void PageItem::SetFrameShape(int count, qreal *vals)
+ {
+ PoLine.resize(0);
+ for (int a = 0; a < count-3; a += 4)
+@@ -4620,7 +4620,7 @@ void PageItem::SetFrameShape(int count,
+
+ void PageItem::SetRectFrame()
+ {
+- static double rect[] = { 0.0, 0.0, 0.0, 0.0,
++ static qreal rect[] = { 0.0, 0.0, 0.0, 0.0,
+ 100.0, 0.0, 100.0, 0.0,
+ 100.0, 0.0, 100.0, 0.0,
+ 100.0, 100.0, 100.0, 100.0,
+@@ -4635,7 +4635,7 @@ void PageItem::SetRectFrame()
+
+ void PageItem::SetOvalFrame()
+ {
+- static double rect[] = { 100.0, 50.0, 100.0, 77.615235,
++ static qreal rect[] = { 100.0, 50.0, 100.0, 77.615235,
+ 50.0, 100.0, 77.615235, 100.0,
+ 50.0, 100.0, 22.385765, 100.0,
+ 0.0, 50.0, 0.0, 77.615235,
+--- scribus-1.4.2.dfsg+r18267.orig/scribus/pageitem.h
++++ scribus-1.4.2.dfsg+r18267/scribus/pageitem.h
+@@ -298,7 +298,7 @@ protected:
+ void DrawObj_PathText(ScPainter *p, double sc);
+ public:
+ void DrawObj_Embedded(ScPainter *p, QRectF e, const CharStyle& style, PageItem* cembedded);
+- void SetFrameShape(int count, double *vals);
++ void SetFrameShape(int count, qreal *vals);
+ void SetRectFrame();
+ void SetOvalFrame();
+ void SetFrameRound();
+--- scribus-1.4.2.dfsg+r18267.orig/scribus/propertiespalette.cpp
++++ scribus-1.4.2.dfsg+r18267/scribus/propertiespalette.cpp
+@@ -4622,7 +4622,7 @@ void PropertiesPalette::MakeIrre(int f,
+ doc->setRedrawBounding(CurItem);
+ break;
+ default:
+- CurItem->SetFrameShape(c, (double*)vals);
++ CurItem->SetFrameShape(c, vals);
+ doc->setRedrawBounding(CurItem);
+ CurItem->FrameType = f+2;
+ break;
+--- scribus-1.4.2.dfsg+r18267.orig/scribus/scribusdoc.h
++++ scribus-1.4.2.dfsg+r18267/scribus/scribusdoc.h
+@@ -1005,7 +1005,7 @@ public: // Public attributes
+ DocumentInformation documentInfo;
+ int appMode;
+ int SubMode;
+- double *ShapeValues;
++ qreal *ShapeValues;
+ int ValCount;
+ QString DocName;
+ QMap UsedFonts;
+--- scribus-1.4.2.dfsg+r18267.orig/scribus/canvasmode_create.cpp
++++ scribus-1.4.2.dfsg+r18267/scribus/canvasmode_create.cpp
+@@ -122,7 +122,7 @@ void CreateMode::drawControls(QPainter*
+ {
+ FPointArray poly;
+ int valCount = m_doc->ValCount;
+- double *vals = m_doc->ShapeValues;
++ qreal *vals = m_doc->ShapeValues;
+ for (int a = 0; a < valCount-3; a += 4)
+ {
+ if (vals[a] < 0)
+--- scribus-1.4.2.dfsg+r18267.orig/scribus/scribus.cpp
++++ scribus-1.4.2.dfsg+r18267/scribus/scribus.cpp
+@@ -7599,7 +7599,7 @@ void ScribusMainWindow::GetBrushPen()
+ }
+ */
+ //CB-->??
+-void ScribusMainWindow::MakeFrame(int f, int c, double *vals)
++void ScribusMainWindow::MakeFrame(int f, int c, qreal *vals)
+ {
+ PageItem *currItem = doc->m_Selection->itemAt(0);
+ switch (f)
+--- scribus-1.4.2.dfsg+r18267.orig/scribus/plugins/imposition/imposition.cpp
++++ scribus-1.4.2.dfsg+r18267/scribus/plugins/imposition/imposition.cpp
+@@ -542,7 +542,7 @@ void Imposition::booklet4p(QList* p
+ }
+ groupcontrol->SetRectFrame();
+
+- double points[32] = {
++ qreal points[32] = {
+ //left upper corner - left lower corner
+ targetDoc->Pages->at(0)->guides.vertical(1,targetDoc->Pages->at(0)->guides.Standard),
+ targetDoc->Pages->at(0)->guides.horizontal(0,targetDoc->Pages->at(i)->guides.Standard),
+@@ -730,7 +730,7 @@ void Imposition::booklet4p(QList* p
+ }
+ groupcontrol->SetRectFrame();
+
+- double points[32] = {
++ qreal points[32] = {
+ //left upper corner - left lower corner
+ 0,
+ 0,
+@@ -893,7 +893,7 @@ void Imposition::booklet4p(QList* p
+ }
+ groupcontrol->SetRectFrame();
+
+- double points[32] = {
++ qreal points[32] = {
+ //left upper corner - left lower corner
+ 0,
+ 0,
+@@ -1047,7 +1047,7 @@ void Imposition::booklet4p(QList* p
+ }
+ groupcontrol->SetRectFrame();
+
+- double points[32] = {
++ qreal points[32] = {
+ //left upper corner - left lower corner
+ targetDoc->Pages->at(0)->guides.vertical(1,targetDoc->Pages->at(0)->guides.Standard),
+ targetDoc->Pages->at(0)->guides.horizontal(0,targetDoc->Pages->at(i)->guides.Standard),
diff --git a/scribus-1.4.5-lppl-fixes.patch b/scribus-1.4.5-lppl-fixes.patch
new file mode 100644
index 0000000..2cc89f3
--- /dev/null
+++ b/scribus-1.4.5-lppl-fixes.patch
@@ -0,0 +1,36 @@
+diff -up scribus-1.4.5/resources/dicts/README_hyph_da_DK.txt.lppl scribus-1.4.5/resources/dicts/README_hyph_da_DK.txt
+--- scribus-1.4.5/resources/dicts/README_hyph_da_DK.txt.lppl 2015-05-07 16:50:30.664715518 -0400
++++ scribus-1.4.5/resources/dicts/README_hyph_da_DK.txt 2015-05-07 16:50:53.288550546 -0400
+@@ -3,6 +3,9 @@ Hyphenation dictionary
+
+ Language: Danish (da DK).
+ Origin: Based on the TeX hyphenation tables
++ http://www.ctan.org/tex-archive/language/hyphenation/dkhyphn/dkhyphn.tex
++ The TeX hyphenation tables are released under the LaTeX Project
++ Public License (LPPL)
+ License: GNU LGPL license.
+ Author: conversion author is Marco Huggenberger
+
+diff -up scribus-1.4.5/resources/dicts/README_is_IS.txt.lppl scribus-1.4.5/resources/dicts/README_is_IS.txt
+--- scribus-1.4.5/resources/dicts/README_is_IS.txt.lppl 2015-05-07 16:51:32.623263721 -0400
++++ scribus-1.4.5/resources/dicts/README_is_IS.txt 2015-05-07 16:51:53.072114610 -0400
+@@ -2,15 +2,14 @@ Hyphenation dictionary
+ ----------------------
+
+ Language: Icelandic (Iceland) (is IS).
+-Origin: Based on the TeX hyphenation tables
++Origin: Based on the TeX hyphenation tables by J�rgen Pind (1987).
++ http://www.ctan.org/tex-archive/language/hyphenation/dkhyphn/dkhyphn.tex
++ The TeX hyphenation tables are released under the LaTeX Project
++ Public License (LPPL)
+ License: LGPL/SISSL license, 2003
+ Author: akig@hi.is (Áki G. Karlsson)
+
+ HYPH is IS hyph_is_IS
+-
+-
+- These patterns were converted from TeX hyphenation patterns by Jörgen Pind
+- (1987).
+
+ --
+ Áki G. Karlsson
diff --git a/scribus-1.4.6-gs-9.24.patch b/scribus-1.4.6-gs-9.24.patch
new file mode 100644
index 0000000..d1212d6
--- /dev/null
+++ b/scribus-1.4.6-gs-9.24.patch
@@ -0,0 +1,10 @@
+--- scribus-1.4.6-orig/scribus/plugins/import/ps/import.prolog 2009-05-08 21:04:32.000000000 +0200
++++ scribus-1.4.6/scribus/plugins/import/ps/import.prolog 2018-09-17 16:05:24.988900385 +0200
+@@ -75,6 +75,7 @@
+ //doimage exec
+ } .forceput
+ end
++/.currentopacityalpha {//.currentopacityalpha} bind def
+ setglobal
+ .bindnow
+
diff --git a/scribus-1.4.6-hunspell.patch b/scribus-1.4.6-hunspell.patch
new file mode 100644
index 0000000..a880c36
--- /dev/null
+++ b/scribus-1.4.6-hunspell.patch
@@ -0,0 +1,12 @@
+--- a/cmake/modules/FindHUNSPELL.cmake
++++ b/cmake/modules/FindHUNSPELL.cmake
+@@ -9,7 +9,7 @@
+ #Based on examples at http://www.vtk.org/Wiki/CMake:How_To_Find_Libraries
+
+ FIND_PATH(HUNSPELL_INCLUDE_DIR hunspell/hunspell.hxx )
+-FIND_LIBRARY(HUNSPELL_LIBRARIES NAMES hunspell-1.3 hunspell-1.2 PATHS /opt/local/lib /usr/local/lib /usr/lib )
++FIND_LIBRARY(HUNSPELL_LIBRARIES NAMES hunspell-1.6 hunspell-1.5 hunspell-1.4 hunspell-1.3 hunspell-1.2 PATHS /opt/local/lib /usr/local/lib /usr/lib )
+
+ INCLUDE(FindPackageHandleStandardArgs)
+ # handle the QUIETLY and REQUIRED arguments and set HUNSPELL_FOUND to TRUE
+
diff --git a/scribus.png b/scribus.png
new file mode 100644
index 0000000..c8437f2
Binary files /dev/null and b/scribus.png differ
diff --git a/scribus.spec b/scribus.spec
index 3e913a6..10af6b1 100644
--- a/scribus.spec
+++ b/scribus.spec
@@ -1,70 +1,53 @@
Name: scribus
-Version: 1.6.5
-Release: %autorelease
-Summary: Desktop Publishing application written in Qt
+Version: 1.4.6
+Release: 14%{?dist}
+Summary: DeskTop Publishing application written in Qt
+Group: Applications/Productivity
# swatches bring in the fun licenses
-License: GPL-2.0-or-later AND OGL-UK-3.0 AND CC0-1.0 AND CC-BY-4.0 AND CC-BY-SA-4.0 AND LicenseRef-Fedora-Public-Domain AND Apache-2.0 AND LGPL-2.0-or-later
+License: GPLv2+ and OGL and CC0 and CC-BY and CC-BY-SA and Public Domain and ASL 2.0 and LGPLv2+
URL: http://www.scribus.net/
-
-# svn export svn://scribus.net/trunk/Scribus scribus-%%{version}
-# tar --exclude-vcs -cJf scribus-%%{version}.tar.xz scribus-%%{version}
-## The following script removes non free contents
-# ./make-free-archive %%{version}
+# ./make-free-archive %{version}
Source0: %{name}-%{version}-free.tar.xz
-#Source0: http://downloads.sourceforge.net/%%{name}/%%{name}-%%{version}.tar.xz
-#Source1: http://downloads.sourceforge.net/%%{name}/%%{name}-%%{version}.tar.xz.asc
+#Source0: http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.xz
+#Source1: http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.xz.asc
+Source2: scribus.png
+Patch1: %{name}-1.4.4-qreal_double.patch
+# fix build with non-free content removed
+Patch2: %{name}-1.4.2-nonfree.patch
+# Fix necessary LPPL attribution
+Patch3: %{name}-1.4.5-lppl-fixes.patch
+# Fix detection of hunspell-1.4+
+Patch4: %{name}-1.4.6-hunspell.patch
+Patch5: %{name}-1.4.6-gs-9.24.patch
-
-BuildRequires: boost-devel
BuildRequires: cmake
BuildRequires: cups-devel
BuildRequires: desktop-file-utils
-BuildRequires: gcc-c++
-BuildRequires: ghostscript
+BuildRequires: lcms2-devel
+BuildRequires: libart_lgpl-devel
+BuildRequires: libjpeg-devel
+BuildRequires: libpng-devel
+BuildRequires: libtiff-devel
+BuildRequires: libxml2-devel
+BuildRequires: openssl-devel
+BuildRequires: python2-devel
+BuildRequires: python2-imaging-devel
+BuildRequires: qt4-devel
+BuildRequires: zlib-devel
+BuildRequires: freetype-devel
+BuildRequires: gnutls-devel
+BuildRequires: cairo-devel
+BuildRequires: hunspell-devel
+BuildRequires: boost-devel
+BuildRequires: podofo-devel
BuildRequires: hyphen-devel
-BuildRequires: libappstream-glib
-BuildRequires: pkgconfig(cairo)
-BuildRequires: pkgconfig(fontconfig)
-BuildRequires: pkgconfig(freetype2) >= 2.13.2
-BuildRequires: pkgconfig(gnutls)
-BuildRequires: pkgconfig(GraphicsMagick)
-BuildRequires: pkgconfig(GraphicsMagick++)
-BuildRequires: pkgconfig(harfbuzz)
-BuildRequires: pkgconfig(hunspell)
-BuildRequires: pkgconfig(icu-uc)
-BuildRequires: pkgconfig(lcms2)
-BuildRequires: pkgconfig(libcdr-0.1)
-BuildRequires: pkgconfig(libfreehand-0.1)
-BuildRequires: pkgconfig(libjpeg)
-BuildRequires: pkgconfig(libmspub-0.1)
-BuildRequires: pkgconfig(libpagemaker-0.0)
-BuildRequires: pkgconfig(libpng)
-BuildRequires: pkgconfig(libpodofo) < 1.0
-BuildRequires: pkgconfig(libqxp-0.0)
-BuildRequires: pkgconfig(librevenge-0.0)
-BuildRequires: pkgconfig(libtiff-4)
-BuildRequires: pkgconfig(libvisio-0.1)
-BuildRequires: pkgconfig(libwpd-0.10)
-BuildRequires: pkgconfig(libwpg-0.3)
-BuildRequires: pkgconfig(libxml-2.0)
-BuildRequires: pkgconfig(libzmf-0.0)
-BuildRequires: pkgconfig(openscenegraph)
-BuildRequires: pkgconfig(openssl)
-BuildRequires: pkgconfig(poppler)
-BuildRequires: pkgconfig(poppler-cpp)
-BuildRequires: pkgconfig(poppler-data)
-BuildRequires: pkgconfig(python3)
-BuildRequires: pkgconfig(Qt5) > 5.14
-BuildRequires: pkgconfig(Qt5Quick)
-BuildRequires: pkgconfig(Qt5UiTools)
-BuildRequires: pkgconfig(Qt5WebKit)
-BuildRequires: pkgconfig(tk)
-BuildRequires: pkgconfig(zlib)
-BuildRequires: python3dist(pillow)
-BuildRequires: python3-qt5-devel
-BuildRequires: python3dist(setuptools)
-BuildRequires: python3-tkinter
-
+Requires: ghostscript
+Requires: python2
+Requires: python2-imaging
+Requires: python2-tkinter
+Requires: shared-mime-info
+Obsoletes: %{name}-doc < %{version}-%{release}
+Obsoletes: %{name}-devel < %{version}-%{release}
%filter_provides_in %{_libdir}/%{name}/plugins
%filter_setup
@@ -82,64 +65,654 @@ import/export and creation of color separations.
%prep
-%autosetup -p1
+%setup -q
+%patch1 -p1 -b .double
+%patch2 -p1 -b .nonfree
+%patch3 -p1
+%patch4 -p1
+%patch5 -p1
+
+# recode man page to UTF-8
+pushd scribus/manpages
+iconv -f ISO8859-2 -t UTF-8 scribus.1.pl > tmp
+touch -r scribus.1.pl tmp
+mv tmp scribus.1.pl
+popd
# fix permissions
chmod a-x scribus/pageitem_latexframe.h
# drop shebang lines from python scripts
-%py3_shebang_fix %{name}/plugins/scriptplugin/{samples,scripts}/*.py
+for f in scribus/plugins/scriptplugin/{samples,scripts}/*.py
+do
+ sed '1{/#!\/usr\/bin\/env\|#!\/usr\/bin\/python/d}' $f > $f.new
+ touch -r $f $f.new
+ mv $f.new $f
+done
+
%build
-%cmake \
- -DWANT_CCACHE=YES \
- -DWANT_CPP17=ON \
- -DWANT_DISTROBUILD=YES \
- -DWANT_GRAPHICSMAGICK=1 \
- -DWANT_HUNSPELL=1 \
-%if "%{_lib}" == "lib64"
- -DWANT_LIB64=YES \
-%endif
- -DWANT_NORPATH=1 \
- -DWITH_BOOST=1 \
- -DWITH_PODOFO=1
-%cmake_build
+mkdir build
+pushd build
+%cmake -DWANT_DISTROBUILD=YES -DWANT_HUNSPELL=YES -DWANT_NOHEADERINSTALL=YES ..
+
+make VERBOSE=1 %{?_smp_mflags}
+popd
+
%install
-%cmake_install
+pushd build
+make install DESTDIR=$RPM_BUILD_ROOT
+popd
-find %{buildroot} -type f -name "*.la" -exec rm -f {} ';'
+install -p -D -m0644 %SOURCE2 ${RPM_BUILD_ROOT}%{_datadir}/pixmaps/scribus.png
+install -p -D -m0644 ${RPM_BUILD_ROOT}%{_datadir}/scribus/icons/scribusdoc.png ${RPM_BUILD_ROOT}%{_datadir}/pixmaps/x-scribus.png
+
+find ${RPM_BUILD_ROOT} -type f -name "*.la" -exec rm -f {} ';'
+
+# install the global desktop file
+rm -f ${RPM_BUILD_ROOT}%{_datadir}/mimelnk/application/*scribus.desktop
+desktop-file-install \
+%if (0%{?fedora} && 0%{?fedora} < 19) || (0%{?rhel} && 0%{?rhel} < 7)
+ --vendor="fedora" \
+%endif
+ --dir=${RPM_BUILD_ROOT}%{_datadir}/applications \
+ scribus.desktop
+
+# remove unwanted stuff
+rm -rf ${RPM_BUILD_ROOT}%{_defaultdocdir}/%{name}
+
+# Register as an application to be visible in the software center
+#
+# NOTE: It would be *awesome* if this file was maintained by the upstream
+# project, translated and installed into the right place during `make install`.
+#
+# See http://www.freedesktop.org/software/appstream/docs/ for more details.
+#
+mkdir -p $RPM_BUILD_ROOT%{_datadir}/appdata
+cat > $RPM_BUILD_ROOT%{_datadir}/appdata/%{name}.appdata.xml <
+
+
+
+ scribus.desktop
+ CC0-1.0
+
+
+ Scribus is a desktop publishing application that allows you to create posters,
+ magazines and books ready to send off to a printing house.
+ It supports professional publishing features, such color separations, CMYK and
+ spot colors, ICC color management, and versatile PDF creation.
+
+
+
+ http://scribus.net/
+
+ http://upload.wikimedia.org/wikipedia/commons/f/f4/Scribus-1.3-Linux.png
+
+
+
+EOF
+
+%post
+touch --no-create %{_datadir}/mime/packages &> /dev/null || :
+
+%postun
+if [ $1 -eq 0 ] ; then
+touch --no-create %{_datadir}/mime/packages &> /dev/null || :
+update-desktop-database &> /dev/null || :
+update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :
+fi
+
+%posttrans
+update-desktop-database &> /dev/null || :
+update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :
-%check
-desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
-appstream-util validate-relax --nonet \
- %{buildroot}%{_metainfodir}/%{name}.appdata.xml
%files
-%license COPYING
-%doc AUTHORS ChangeLog COPYING README LINKS TRANSLATION
+%doc AUTHORS ChangeLog COPYING LINKS README
%{_bindir}/%{name}
%{_libdir}/%{name}/
-%{_metainfodir}/%{name}.appdata.xml
-%{_datadir}/applications/%{name}.desktop
+%{_datadir}/appdata/*%{name}.appdata.xml
+%{_datadir}/applications/*%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
-%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
-%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
-%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
-%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
-%{_datadir}/icons/hicolor/512x512/apps/%{name}.png
-%{_datadir}/icons/hicolor/1024x1024/apps/%{name}.png
-%{_datadir}/icons/hicolor/16x16/mimetypes/application-vnd.%{name}.png
-%{_datadir}/icons/hicolor/32x32/mimetypes/application-vnd.%{name}.png
-%{_datadir}/icons/hicolor/64x64/mimetypes/application-vnd.%{name}.png
-%{_datadir}/icons/hicolor/128x128/mimetypes/application-vnd.%{name}.png
-%{_datadir}/icons/hicolor/256x256/mimetypes/application-vnd.%{name}.png
+%{_datadir}/pixmaps/*
%{_datadir}/%{name}/
+%exclude %{_datadir}/%{name}/samples/*.py[co]
+%exclude %{_datadir}/%{name}/scripts/*.py[co]
%{_mandir}/man1/*
-%exclude %{_mandir}/pl/man1/*
-%exclude %{_mandir}/de/man1/*
+%{_mandir}/pl/man1/*
+%{_mandir}/de/man1/*
%changelog
-%autochangelog
+* Mon Sep 17 2018 Michael J Gruber - 1.4.6-14
+- fix EPS import (bz #1628943)
+
+* Sat Jul 14 2018 Fedora Release Engineering - 1.4.6-13
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild
+
+* Wed Jul 11 2018 Sandro Mani - 1.4.6-12
+- Rebuild (podofo)
+
+* Mon Feb 12 2018 Iryna Shcherbina - 1.4.6-11
+- Update Python 2 dependency declarations to new packaging standards
+ (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)
+
+* Fri Feb 09 2018 Fedora Release Engineering - 1.4.6-10
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild
+
+* Thu Aug 03 2017 Fedora Release Engineering - 1.4.6-9
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild
+
+* Thu Jul 27 2017 Fedora Release Engineering - 1.4.6-8
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild
+
+* Fri Jul 07 2017 Igor Gnatenko - 1.4.6-7
+- Rebuild due to bug in RPM (RHBZ #1468476)
+
+* Fri Apr 07 2017 Yaakov Selkowitz - 1.4.6-6
+- Fix detection of latest hunspell for spell-checking support (#1425305)
+
+* Mon Feb 06 2017 Kalev Lember - 1.4.6-5
+- Rebuilt for Boost 1.63
+
+* Thu Feb 02 2017 Sandro Mani - 1.4.6-4
+- Rebuild (podofo)
+
+* Fri Jan 27 2017 Jonathan Wakely - 1.4.6-3
+- Rebuilt for Boost 1.63
+
+* Fri Sep 23 2016 Jon Ciesla - 1.4.6-2
+- podofo rebuild.
+
+* Tue May 24 2016 Jon Ciesla - 1.4.6-1
+- 1.4.6
+
+* Thu Feb 04 2016 Fedora Release Engineering - 1.4.5-9
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild
+
+* Fri Jan 15 2016 Jonathan Wakely - 1.4.5-8
+- Rebuilt for Boost 1.60
+
+* Tue Jan 12 2016 Tom Callaway - 1.4.5-7
+- fix license tag, remove found non-free swatches (bz 1297262)
+
+* Fri Sep 18 2015 Richard Hughes - 1.4.5-6
+- Use a bigger resolution application icon
+
+* Thu Aug 27 2015 Jonathan Wakely - 1.4.5-5
+- Rebuilt for Boost 1.59
+
+* Wed Jul 29 2015 Fedora Release Engineering - 1.4.5-4
+- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159
+
+* Wed Jul 22 2015 David Tardon - 1.4.5-3
+- rebuild for Boost 1.58
+
+* Fri Jun 19 2015 Fedora Release Engineering - 1.4.5-2
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild
+
+* Thu May 7 2015 Tom Callaway 1.4.5-1
+- update to 1.4.5
+- drop non-free and questionable hyphen dic files (bz 1219415)
+- fix necessary LPPL attributions
+
+* Thu Mar 26 2015 Richard Hughes - 1.4.4-7
+- Add an AppData file for the software center
+
+* Tue Jan 27 2015 Petr Machata - 1.4.4-6
+- Rebuild for boost 1.57.0
+
+* Thu Aug 28 2014 Dan Horák - 1.4.4-5
+- switch to Debian patch for the qreal vs double conflict on ARM (fixes #1076885)
+
+* Wed Aug 20 2014 Kevin Fenzi - 1.4.4-4
+- Rebuild for rpm bug 1131892
+
+* Mon Aug 18 2014 Fedora Release Engineering - 1.4.4-3
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild
+
+* Sat Aug 09 2014 Rex Dieter 1.4.4-2
+- optimize/update scriptlets
+
+* Fri Jun 6 2014 Tom Callaway - 1.4.4-1
+- update to 1.4.4, drop non-free dot files
+
+* Fri May 23 2014 Petr Machata - 1.4.3-3
+- Rebuild for boost 1.55.0
+
+* Thu Sep 19 2013 Dan Horák - 1.4.3-2
+- fix the double patch (#1009979)
+
+* Mon Aug 19 2013 Dan Horák - 1.4.3-1
+- update to 1.4.3 (#990030)
+- update for unversioned docdir
+
+* Sun Aug 04 2013 Fedora Release Engineering - 1.4.2-7
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild
+
+* Tue Jul 30 2013 Petr Machata - 1.4.2-6
+- Rebuild for boost 1.54.0
+
+* Mon Feb 25 2013 Toshio Kuratomi - 1.4.2-5
+- Remove --vendor from desktop-file-install for F19+ https://fedorahosted.org/fesco/ticket/1077
+
+* Wed Jan 30 2013 Dan Horák - 1.4.2-4
+- update for Pillow (#896301)
+
+* Mon Jan 21 2013 Adam Tkac - 1.4.2-3
+- rebuild due to "jpeg8-ABI" feature drop
+
+* Fri Jan 18 2013 Dan Horák - 1.4.2-2
+- use hunspell to be consistent with the rest of the system
+
+* Tue Jan 15 2013 Dan Horák - 1.4.2-1
+- update to 1.4.2
+- remove non-free content from source archive (#887221)
+- drop doc and devel sub-packages
+- switch to lcms2
+
+* Fri Dec 21 2012 Adam Tkac - 1.4.1-4
+- rebuild against new libjpeg
+
+* Thu Aug 9 2012 Peter Robinson - 1.4.1-3
+- Add patch to fix FTBFS on ARM
+
+* Sat Jul 21 2012 Fedora Release Engineering - 1.4.1-2
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild
+
+* Sun May 06 2012 Dan Horák - 1.4.1-1
+- update to 1.4.1
+
+* Wed Mar 07 2012 Dan Horák - 1.4.0-5
+- fix crash at export as image (rhbz#800765)
+
+* Tue Feb 28 2012 Fedora Release Engineering - 1.4.0-4
+- Rebuilt for c++ ABI breakage
+
+* Sat Jan 14 2012 Fedora Release Engineering - 1.4.0-3
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild
+
+* Tue Jan 03 2012 Dan Horák - 1.4.0-2
+- the swatches/profiles patches were submitted to upstream bugtracker
+
+* Mon Jan 02 2012 Dan Horák - 1.4.0-1.1
+- install profiles and swatches to datadir
+- use versioned docdir
+
+* Mon Jan 02 2012 Dan Horák - 1.4.0-1
+- update to 1.4.0
+
+* Fri Jun 24 2011 Dan Horák - 1.3.9-6
+- fix build with cups 1.5 (#716107)
+
+* Wed May 04 2011 Dan Horák - 1.3.9-5
+- rebuilt against podofo 0.9.1
+
+* Thu Apr 14 2011 Dan Horák - 1.3.9-4
+- rebuilt against podofo 0.9.0
+
+* Wed Feb 09 2011 Fedora Release Engineering - 1.3.9-3
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild
+
+* Mon Dec 20 2010 Dan Horák - 1.3.9-2
+- run update-desktop-database in scriptlets too (#664318)
+
+* Tue Nov 30 2010 Dan Horák - 1.3.9-1
+- update to 1.3.9
+- filter unwanted Provides
+
+* Wed Nov 03 2010 Dan Horák - 1.3.8-3
+- rebuilt against podofo 0.8.4
+
+* Fri Oct 22 2010 Dan Horák - 1.3.8-2
+- rebuilt against podofo 0.8.3
+
+* Mon Aug 16 2010 Dan Horák - 1.3.8-1
+- update to 1.3.8
+
+* Tue Jul 27 2010 David Malcolm - 1.3.7-5
+- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild
+
+* Tue Jun 15 2010 Dan Horák - 1.3.7-4
+- fix crash when selecting frame (#604124)
+
+* Tue Jun 15 2010 Dan Horák - 1.3.7-3
+- show icons in shapes menu (#603921)
+
+* Tue Jun 08 2010 Dan Horák - 1.3.7-2
+- rebuilt with podofo 0.8.1
+
+* Tue Jun 1 2010 Dan Horák - 1.3.7-1
+- update to final 1.3.7
+
+* Thu Apr 29 2010 Dan Horák - 1.3.6-4
+- fix build with podofo 0.8.0
+
+* Thu Apr 29 2010 Dan Horák - 1.3.6-3
+- rebuilt for podofo 0.8.0
+
+* Wed Mar 31 2010 Dan Horák - 1.3.6-2
+- added 2 patches for rawhide
+
+* Mon Mar 29 2010 Dan Horák - 1.3.6-1
+- update to final 1.3.6
+
+* Wed Nov 25 2009 Dan Horák - 1.3.5.1-5
+- fixed a crash when closing a hyphenator object (#537677)
+
+* Thu Aug 27 2009 Tomas Mraz - 1.3.5.1-4
+- rebuilt with new openssl
+
+* Tue Aug 25 2009 Dan Horák - 1.3.5.1-3
+- drop shebang line from python scripts
+- don't package precompiled python scripts
+
+* Thu Aug 20 2009 Dan Horák - 1.3.5.1-1
+- update to final 1.3.5.1
+- drop the upstreamed "install-headers" patch
+- always install doc subpackage (#446148)
+- full changelog: http://www.scribus.net/?q=node/193
+
+* Wed Jul 29 2009 Dan Horák - 1.3.5-0.17.rc3
+- don't use parallel build on s390x
+
+* Sun Jul 26 2009 Fedora Release Engineering - 1.3.5-0.16.rc3
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild
+
+* Tue Jul 21 2009 Dan Horák - 1.3.5-0.15.rc3
+- update to 1.3.5-rc3
+- use system hyphen library (#506074)
+- fix update path for the doc subpackage (#512498)
+- preserve directories when installing headers (#511800)
+
+* Thu Jun 4 2009 Dan Horák - 1.3.5-0.14.rc2
+- update to 1.3.5-rc2
+
+* Mon May 18 2009 Dan Horák - 1.3.5-0.13.beta
+- rebuilt with podofo enabled
+
+* Wed Apr 22 2009 Dan Horák - 1.3.5-0.12.beta
+- update to 1.3.5.beta
+- make docs subpackage noarch
+- drop outdated Obsoletes/Provides
+
+* Sun Mar 29 2009 Dan Horák - 1.3.5-0.11.20090329svn13359
+- update to revision 13359
+- add aspell-devel and boost-devel as BR
+- update release tag to conform to the pre-release versioning guideline
+
+* Wed Feb 25 2009 Fedora Release Engineering - 1.3.5-0.10.12516svn
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild
+
+* Sat Jan 17 2009 Tomas Mraz - 1.3.4-0.9.12516svn
+- rebuild with new openssl
+
+* Thu Dec 04 2008 Ignacio Vazquez-Abrams - 1.3.5-0.8.12516svn
+- Rebuild for Python 2.6
+
+* Tue Dec 2 2008 Dan Horák - 1.3.5-0.7.12516svn
+- fix directory ownership in doc subpackage (#474041)
+
+* Sun Nov 30 2008 Ignacio Vazquez-Abrams - 1.3.5-0.6.12516svn
+- Rebuild for Python 2.6
+
+* Mon Oct 13 2008 Dan Horák 1.3.5-0.5.12516svn
+- install global desktop file instead of KDE-only one (#461124)
+- little cleanup
+
+* Fri Sep 05 2008 Andreas Bierfert
+- 1.3.5-0.4.12516svn
+- new svn snapshot
+
+* Sun Jul 27 2008 Andreas Bierfert
+- 1.3.5-0.3.12419svn
+- new svn snapshot
+
+* Mon Jul 21 2008 Andreas Bierfert
+- 1.3.5-0.2.12404svn
+- svn snapshot
+
+* Mon Feb 18 2008 Fedora Release Engineering - 1.3.4-5
+- Autorebuild for GCC 4.3
+
+* Mon Feb 11 2008 Andreas Bierfert - 1.3.4-4
+- Rebuilt for gcc43
+
+* Fri Dec 28 2007 Andreas Bierfert
+- 1.3.4-3
+- fix inclusion of python scripts as proposed by Todd Zullinger (#312091)
+- fix desktop file
+
+* Thu Aug 23 2007 Andreas Bierfert
+- 1.3.4-2
+- rebuild for buildid
+- new license tag
+
+* Sat Jun 02 2007 Andreas Bierfert
+1.3.4
+- version upgrade
+
+* Mon Dec 04 2006 Andreas Bierfert
+1.3.3.6-1
+- version upgrade
+
+* Sat Nov 11 2006 Andreas Bierfert
+1.3.3.5-1
+- version upgrade
+
+* Wed Oct 04 2006 Andreas Bierfert
+1.3.3.4-1
+- version upgrade
+
+* Fri Sep 15 2006 Andreas Bierfert
+1.3.3.3-1
+- version upgrade (#205962)
+
+* Sun Jun 18 2006 Andreas Bierfert
+1.3.3.2-2
+- bump
+
+* Tue May 30 2006 Andreas Bierfert
+1.3.3.2-1
+- version upgrade
+
+* Sat Apr 22 2006 Andreas Bierfert
+1.3.3.1-1
+- version upgrade
+
+* Tue Mar 28 2006 Andreas Bierfert
+1.3.3-1
+- version upgrade
+- add BR gnutls-devel
+
+* Sat Mar 18 2006 Andreas Bierfert
+1.3.2-1
+- upgrade to beta version
+
+* Thu Feb 16 2006 Andreas Bierfert
+1.2.4.1-4
+- Rebuild for Fedora Extras 5
+
+* Wed Feb 08 2006 Andreas Bierfert
+1.2.4.1-3
+- add missing requires python-imaging
+
+* Sat Jan 21 2006 Andreas Bierfert
+1.2.4.1-2
+- rebuild (#178494)
+
+* Wed Jan 18 2006 Andreas Bierfert
+1.2.4.1-1
+- version upgrade
+
+* Thu Jul 7 2005 Tom "spot" Callaway 1.2.2.1-2
+- use dist tag for sanity between branches
+
+* Tue Jul 5 2005 P Linnell - 1.2.2.1-1
+- 1.2.2.1 released to fix crash on open with certain 1.2.1 docs
+
+* Sun Jul 3 2005 P Linnell - 1.2.2-0.fc4
+- 1.2.2 final
+
+* Tue Jun 28 2005 P Linnell - 1.2.2cvs-0
+- test build for 1.2.2cvs
+- Add freetype2 explicit build requirement
+- Add obsoletes. See PACKAGING in the source tarball
+- Change the description per PACKAGING
+- Bump required python. 2.2 is no longer supported.
+
+
+* Sun May 22 2005 Jeremy Katz - 1.2.1-5
+- rebuild on all arches
+
+* Fri Apr 7 2005 Michael Schwendt
+- rebuilt
+
+* Sun Feb 06 2005 Phillip Compton - 1.2.1-3
+- Bumped BR on qt-devel to 3.3.
+
+* Thu Feb 3 2005 Michael Schwendt - 1.2.1-2
+- Fix x86_64 build and summary.
+
+* Sun Jan 09 2005 Phillip Compton - 1.2.1-1
+- 1.2.1.
+
+* Sat Dec 04 2004 Phillip Compton - 1.2.1-0.1.cvs20041118
+- cvs snapshot.
+
+* Wed Nov 11 2004 Phillip Compton - 1.2-0.fdr.3
+- Redirect output in post/postun, to avoid failure.
+
+* Wed Nov 10 2004 Phillip Compton - 1.2-0.fdr.2
+- Mime-type corrections for FC3.
+- Dropped redundent BR XFree86-devel.
+
+* Thu Aug 26 2004 Phillip Compton - 0:1.2-0.fdr.1
+- 1.2.
+- Dropping old obsoletes/provides (don't know of anyone using them).
+
+* Thu Aug 19 2004 Phillip Compton - 0:1.2-0.fdr.0.RC1
+- 1.2RC1.
+
+* Sat Aug 07 2004 Phillip Compton - 0:1.1.7-0.fdr.4
+- mime info/icon for .sla files.
+
+* Fri Jul 10 2004 Phillip Compton - 0:1.1.7-0.fdr.3
+- BuildReq openssl-devel (#1727).
+
+* Thu Jun 10 2004 Phillip Compton - 0:1.1.7-0.fdr.2
+- Source0 allows direct download (#1727).
+- Req tkinter (#1727).
+
+* Sun Jun 06 2004 Phillip Compton - 0:1.1.7-0.fdr.1
+- Updated to 1.1.7.
+- Re-added _smp_mflags.
+
+* Mon May 24 2004 Phillip Compton - 0:1.1.6-0.fdr.3
+- Add Application Category to desktop entry.
+
+* Sun Apr 11 2004 Phillip Compton - 0:1.1.6-0.fdr.2
+- Bump ghostscript Req to 7.07.
+- URL scribus.net.
+
+* Tue Apr 06 2004 Phillip Compton - 0:1.1.6-0.fdr.1
+- Updated to 1.1.6.
+- Using upstream desktop entry.
+
+* Sat Feb 14 2004 Phillip Compton - 0:1.1.5-0.fdr.1
+- Updated to 1.1.5.
+
+* Sun Dec 21 2003 Phillip Compton - 0:1.1.4-0.fdr.1
+- Updated to 1.1.4.
+
+* Thu Dec 04 2003 Phillip Compton - 0:1.1.3-0.fdr.2
+- Dropped LDFLAGS="-lm"
+- Added --with-pythondir=%%{_prefix}
+- Req ghostscript.
+
+* Sun Nov 30 2003 Phillip Compton - 0:1.1.3-0.fdr.1
+- Updated to 1.1.3.
+- Removed _smp_mflags.
+
+* Tue Nov 18 2003 Phillip Compton - 0:1.1.2-0.fdr.2
+- Req python.
+- Provides scribus-scripting.
+
+* Sun Nov 09 2003 Phillip Compton - 0:1.1.2-0.fdr.1
+- Updated to 1.1.2.
+- Obsoletes scribus-scripting.
+
+* Sat Oct 11 2003 Phillip Compton - 0:1.1.1-0.fdr.2
+- BuildReq littlecms-devel -> lcms-devel.
+
+* Thu Oct 09 2003 Phillip Compton - 0:1.1.1-0.fdr.1
+- Updated to 1.1.1.
+- BuildReq littlecms-devel.
+- BuildReq libart_lgpl-devel.
+
+* Wed Sep 10 2003 Phillip Compton - 0:1.0.1-0.fdr.1
+- Updated to 1.0.1.
+- Split off devel package for headers.
+- No longer Obsoletes scribus-i18n-en
+
+* Thu Jul 24 2003 Phillip Compton - 0:1.0-0.fdr.3
+- desktop entry terminal=0 -> false.
+
+* Tue Jul 15 2003 Phillip Compton - 0:1.0-0.fdr.2
+- Added Obsoletes scribus-i18n-en.
+
+* Tue Jul 15 2003 Phillip Compton - 0:1.0-0.fdr.1
+- Updated to 1.0.
+
+* Tue Jul 01 2003 Phillip Compton - 0:1.0-0.fdr.0.1.rc1
+- Updated to 1.0RC1.
+
+* Fri Jun 20 2003 Phillip Compton - 0:0.9.11.1-0.fdr.1
+- Updated to 0.9.11.1.
+- Added obsoletes scribus-svg.
+
+* Sun May 25 2003 Phillip Compton - 0:0.9.10-0.fdr.3
+- Using make DESTDIR= workaround for plugin issue.
+- Removed post/postun ldconfig.
+- Removed devel subpackage.
+
+* Mon May 19 2003 Phillip Compton - 0:0.9.10-0.fdr.2
+- Explicitly set file permission on icon.
+- Created devel package.
+- Removed .la files.
+- Added ChangeLog to Documentation.
+
+* Sun May 18 2003 Phillip Compton - 0:0.9.10-0.fdr.1
+- Updated to 0.9.10.
+- buildroot -> RPM_BUILD_ROOT.
+
+* Sat Apr 26 2003 Phillip Compton - 0:0.9.9-0.fdr.3
+- Added BuildRequires for cups-devel.
+
+* Thu Apr 24 2003 Phillip Compton - 0:0.9.9-0.fdr.2
+- Added BuildRequires for libtiff-devel.
+- Added line to help package find tiff.
+
+* Sun Apr 20 2003 Phillip Compton - 0:0.9.9-0.fdr.1
+- Updated to 0.9.9.
+- Added line for QT.
+
+* Thu Apr 10 2003 Phillip Compton - 0:0.9.8-0.fdr.3.rh90
+- Added missing BuildRequires.
+- Corrected Group.
+
+* Tue Apr 01 2003 Phillip Compton - 0:0.9.8-0.fdr.2
+- Added desktop-file-utils to BuildRequires.
+- Changed category to X-Fedora-Extra.
+- Added Epoch:0.
+
+* Thu Mar 27 2003 Phillip Compton - 0.9.8-0.fdr.1
+- Initial RPM release.
diff --git a/sources b/sources
index 9563bfe..5242cb4 100644
--- a/sources
+++ b/sources
@@ -1 +1 @@
-SHA512 (scribus-1.6.5-free.tar.xz) = f023b42e7c59447c52bc41adcb2b4800568d1cf8c88a5b3d6b155f78403a5c92b518ed95e74a20d671e043c206757b0a0e4724b1562ec814901422364f326dfe
+106b2b55bfb87cab65d2d952dbaf7fea scribus-1.4.6-free.tar.xz
diff --git a/make-free-archive.sh b/make-free-archive.sh
index 2b490bb..a8f90ad 100755
--- a/make-free-archive.sh
+++ b/make-free-archive.sh
@@ -11,7 +11,6 @@ nv=scribus-${version}
archive=${nv}.tar.xz
freearchive=${nv}-free.tar.xz
-echo "Verify if source available. Download may be needed"
[ -f ${archive} ] || curl -OL http://downloads.sourceforge.net/scribus/scribus-${version}.tar.xz
echo "Extracting sources ..."
@@ -21,36 +20,35 @@ tar -xJf $archive
pushd ${nv}
# remove docs
-rm -r doc
-sed -i '/add_subdirectory(doc)/d' CMakeLists.txt
-echo "doc folder removed"
+rm -r scribus/doc
-# remove non-free profiles
-rm resources/profiles/{GenericCMYK.icm,GenericCMYK.txt,sRGB.icm,srgb.license}
-sed -i '/GenericCMYK/d' resources/profiles/CMakeLists.txt
-sed -i '/sRGB.icm/d' resources/profiles/CMakeLists.txt
-sed -i '/srgb.license/d' resources/profiles/CMakeLists.txt
-echo "Non-free profiles removed"
+# remove non-free profile
+rm scribus/profiles/{sRGB.icm,srgb.license}
+
+# remove non-free content from swatches
+rm resources/swatches/*.eps
+rm resources/swatches/dtp-studio-free-palettes-license.rtf
-# remove non-free swatches
rm resources/swatches/Galaxy_*
rm resources/swatches/Resene_*
+rm resources/swatches/COPYING_RESENE.txt
+rm resources/swatches/NAA*
+
+rm resources/swatches/GiveLife_Color_System_*.xml
+rm resources/swatches/givelife_colors_license.rtf
+
rm resources/swatches/Federal_Identity_Program.xml
-echo "Non-free swatches removed"
# Remove non-free (CC-BY-SA-NC) dot files
rm resources/editorconfig/dot.*
-sed -i '/dot.svg/d' resources/editorconfig/CMakeLists.txt
-echo "Non-free dot files removed"
-# Remove non-free dicts files
-rm -r resources/dicts
-sed -i '/dicts/d' CMakeLists.txt
-echo "Non-free dicts removed"
+# Remove non-free dic files
+rm resources/dicts/hyph_fi.dic
+
+# Remove license unknown dic files
+rm resources/dicts/hyph_ia.dic resources/dicts/hyph_sv.dic
popd
echo "Creating sources ..."
tar cf - ${nv} | xz > ${freearchive}
-echo "Source free archives created"
-echo "Task completed"